#!/usr/bin/env python3
#
# Copytright 2021 Graviti. Licensed under MIT License.
#
# pylint: disable=invalid-name

"""Dataloader of the nuScenes dataset."""

from tensorbay.opendataset.nuScenes.loader import nuScenes

__all__ = ["nuScenes"]
